@@ -13,17 +13,14 @@ from twisted.web import http
 from twisted.web.http import RESPONSES
 from w3lib import html
 
-from scrapy.http import Response, HtmlResponse, TextResponse
+from scrapy.utils.decorators import deprecated
+
+
+@deprecated
+def body_or_str(*a, **kw):
+    from scrapy.utils.iterators import _body_or_str
+    return _body_or_str(*a, **kw)
 
-def body_or_str(obj, unicode=True):
-    assert isinstance(obj, (Response, basestring)), \
-        "obj must be Response or basestring, not %s" % type(obj).__name__
-    if isinstance(obj, Response):
-        return obj.body_as_unicode() if unicode else obj.body
-    elif isinstance(obj, str):
-        return obj.decode('utf-8') if unicode else obj
-    else:
-        return obj if unicode else obj.encode('utf-8')
 
 _baseurl_cache = weakref.WeakKeyDictionary()
 def get_base_url(response):
@@ -56,7 +53,10 @@ def response_status_message(status):
     >>> response_status_message(404)
     '404 Not Found'
     """
-    return '%s %s' % (status, http.responses.get(int(status)))
+    # Implicit decode/encode is on purpose to force native strings
+    # This is properly fixed in Scrapy >=1.1 at revision faf9265
+    reason = http.RESPONSES.get(int(status), "Unknown Status").decode('utf8', errors='replace')
+    return '{} {}'.format(status, reason)
 
 def response_httprepr(response):
     """Return raw HTTP representation (as string) of the given response. This
@@ -75,6 +75,7 @@ def open_in_browser(response, _openfunc=webbrowser.open):
     """Open the given response in a local web browser, populating the <base>
     tag for external links to work
     """
+    from scrapy.http import HtmlResponse, TextResponse
     # XXX: this implementation is a bit dirty and could be improved
     body = response.body
     if isinstance(response, HtmlResponse):
